@@ -1,4 +1,4 @@
-/* $Id: config.c 28292 2008-10-18 12:40:12Z kelnos $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2003-2006 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- *                                                                              
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *                                                                              
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -39,7 +39,7 @@
 
 #include <gmodule.h>
 
-#include <libxfcegui4/libxfcegui4.h>
+#include <libxfce4ui/libxfce4ui.h>
 
 #include <libxfsm/xfsm-splash-engine.h>
 
@@ -68,6 +68,9 @@ enum
 };
 
 
+G_MODULE_EXPORT void config_init (XfsmSplashConfig *config);
+
+
 static GtkTargetEntry dst_targets[] =
 {
   { "text/uri-list", 0, TARGET_URI },
@@ -283,7 +286,7 @@ config_do_install_theme (const gchar *path,
 static void
 config_dropped (GtkWidget *treeview, GdkDragContext *context,
                 gint x, gint y, GtkSelectionData *data,
-                guint info, guint time, gpointer user_data)
+                guint info, guint time_, gpointer user_data)
 {
   gboolean succeed = FALSE;
   GList   *fnames;
@@ -303,7 +306,7 @@ config_dropped (GtkWidget *treeview, GdkDragContext *context,
       gnome_uri_list_free_strings (fnames);
     }
 
-  gtk_drag_finish (context, succeed, FALSE, time);
+  gtk_drag_finish (context, succeed, FALSE, time_);
 }
 
 
@@ -330,9 +333,16 @@ config_install_theme (GtkWidget *item,
 
       if (!config_do_install_theme (file, treeview))
         {
-          xfce_err (_("Unable to install splash theme from file %s, "
-                      "please check that the file is a valid splash "
-                      "theme archive."), file);
+          gchar *primary = g_strdup_printf (_("Unable to install splash theme from file \"%s\""),
+                                            file);
+          xfce_message_dialog (GTK_WINDOW (toplevel),
+                               _("Theme File Error"),
+                               GTK_STOCK_DIALOG_ERROR,
+                               primary,
+                               _("Please check that the file is a valid splash "
+                                 "theme archive."),
+                               GTK_STOCK_CLOSE, GTK_RESPONSE_ACCEPT, NULL);
+          g_free (primary);
         }
 
       g_free (file);
@@ -356,6 +366,8 @@ config_remove_theme (GtkWidget *item,
   gchar        *name;
   gchar*        argv[4];
   gint          status;
+  GError       *error = NULL;
+  gchar        *error_msg = NULL;
 
   iter = (GtkTreeIter *) g_object_get_data (G_OBJECT (menu), "iter");
   if (G_UNLIKELY (iter == NULL))
@@ -379,12 +391,18 @@ config_remove_theme (GtkWidget *item,
   argv[3] = NULL;
 
   result = g_spawn_sync (NULL, argv, NULL, 0, NULL, NULL,
-                         NULL, NULL, &status, NULL);
+                         NULL, &error_msg, &status, NULL);
 
   if (!result || status != 0)
     {
-      xfce_err (_("Unable to remove splash theme \"%s\" from directory "
-                  "%s."), name, directory);
+      if (!error && error_msg)
+        g_set_error_literal (&error, G_SPAWN_ERROR, G_SPAWN_ERROR_FAILED, error_msg);
+
+      xfce_dialog_show_error (NULL, error,
+                              _("Unable to remove splash theme \"%s\" from directory %s."),
+                              name, directory);
+      if (error)
+        g_error_free (error);
     }
   else
     {
@@ -393,6 +411,7 @@ config_remove_theme (GtkWidget *item,
 
   g_free (directory);
   g_free (name);
+  g_free (error_msg);
 }
 #endif
 
@@ -407,7 +426,7 @@ config_do_export_theme (const gchar *name,
   gchar   *themerc;
   gchar   *argv[4];
   gint     status;
-  
+
   resource = g_strconcat (name, "/balou/themerc", NULL);
   themerc = xfce_resource_lookup (XFCE_RESOURCE_THEMES, resource);
   g_free (resource);
@@ -468,18 +487,19 @@ config_export_theme (GtkWidget *item,
     return;
 
   toplevel = gtk_widget_get_toplevel (GTK_WIDGET (treeview));
-  dialog = xfce_file_chooser_new (_("Choose theme filename..."),
-                                  GTK_WINDOW (toplevel),
-                                  XFCE_FILE_CHOOSER_ACTION_SAVE,
-                                  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                  GTK_STOCK_SAVE, GTK_RESPONSE_OK,
-                                  NULL);
+
+  dialog = gtk_file_chooser_dialog_new (_("Choose theme filename..."),
+                                        GTK_WINDOW (toplevel),
+                                        GTK_FILE_CHOOSER_ACTION_SAVE,
+                                        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                                        GTK_STOCK_SAVE, GTK_RESPONSE_OK,
+                                        NULL);
   file = g_strconcat (name, ".tar.gz", NULL);
-  xfce_file_chooser_set_current_name (XFCE_FILE_CHOOSER (dialog), file);
+  gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (dialog), file);
   g_free (file);
   if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK)
     {
-      file = xfce_file_chooser_get_filename (XFCE_FILE_CHOOSER (dialog));
+      file = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
 
       config_do_export_theme (name, file);
 
@@ -504,7 +524,7 @@ config_popup_menu (GtkWidget      *treeview,
   gchar     *resource;
   gchar     *name;
   guint      button;
-  guint      time;
+  guint      time_;
 
   menu = (GtkWidget *) g_object_get_data (G_OBJECT (treeview), "popup-menu");
   if (GTK_IS_WIDGET (menu))
@@ -512,12 +532,12 @@ config_popup_menu (GtkWidget      *treeview,
       if (event != NULL)
         {
           button = event->button;
-          time = event->time;
+          time_ = event->time;
         }
       else
         {
           button = 0;
-          time = gtk_get_current_event_time ();
+          time_ = gtk_get_current_event_time ();
         }
 
 #ifdef RM_CMD
@@ -548,7 +568,7 @@ config_popup_menu (GtkWidget      *treeview,
                               (GDestroyNotify) g_free);
       g_object_set_data (G_OBJECT (menu), "tree-view", treeview);
 
-      gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, button, time);
+      gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, button, time_);
     }
 }
 
@@ -660,7 +680,7 @@ extract_local_path (gchar *uri)
 			return path;	/* ///path */
 
     our_host_name = xfce_gethostname ();
-		if (strlen(our_host_name) == path - uri - 2 &&
+		if ((int)strlen(our_host_name) == path - uri - 2 &&
 			strncmp(uri + 2, our_host_name, path - uri - 2) == 0)
       {
         g_free (our_host_name);
@@ -717,7 +737,7 @@ config_drag_data_get (GtkWidget        *treeview,
                       GdkDragContext   *context,
                       GtkSelectionData *selection_data,
                       guint             info,
-                      guint32           time)
+                      guint32           time_)
 {
   GtkTreeSelection *selection;
   GtkTreeModel     *model;
@@ -822,7 +842,7 @@ config_selection_changed (GtkTreeSelection *selection,
 }
 
 
-GtkWidget*
+static GtkWidget*
 config_create (XfsmSplashRc *rc)
 {
   GtkTreeSelection  *selection;
@@ -836,19 +856,20 @@ config_create (XfsmSplashRc *rc)
   GtkWidget         *swin;
   GtkWidget         *vbox;
   gchar             *theme;
+  GtkWidget         *bin;
 
   theme = xfsm_splash_rc_read_entry (rc, "Theme", "Default");
 
   page = gtk_vbox_new (FALSE, BORDER);
   gtk_container_set_border_width (GTK_CONTAINER (page), BORDER);
 
-  frame = xfce_framebox_new (_("Balou theme"), TRUE);
+  frame = xfce_gtk_frame_box_new (_("Balou theme"), &bin);
   gtk_box_pack_start (GTK_BOX (page), frame, TRUE, TRUE, 0);
   vbox = gtk_vbox_new (FALSE, 0);
-  xfce_framebox_add (XFCE_FRAMEBOX (frame), vbox);
+  gtk_container_add (GTK_CONTAINER (bin), vbox);
 
   swin = gtk_scrolled_window_new (NULL, NULL);
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (swin), 
+  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (swin),
                                   GTK_POLICY_NEVER,
                                   GTK_POLICY_AUTOMATIC);
   gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (swin),
