@@ -60,13 +60,13 @@
 #include <libxfsm/xfsm-util.h>
 
 #include <xfce4-session/ice-layer.h>
-#include <xfce4-session/shutdown.h>
 #include <xfce4-session/sm-layer.h>
 #include <xfce4-session/xfsm-dns.h>
 #include <xfce4-session/xfsm-global.h>
 #include <xfce4-session/xfsm-manager.h>
+#include <xfce4-session/xfsm-shutdown.h>
 #include <xfce4-session/xfsm-startup.h>
-#include "xfsm-error.h"
+#include <xfce4-session/xfsm-error.h>
 
 static gboolean opt_disable_tcp = FALSE;
 static gboolean opt_version = FALSE;
@@ -90,7 +90,7 @@ setup_environment (void)
   sm = g_getenv ("SESSION_MANAGER");
   if (sm != NULL && strlen (sm) > 0)
     {
-      fprintf (stderr, "xfce4-session: Another session manager is already running\n");
+      g_printerr ("%s: Another session manager is already running\n", PACKAGE_NAME);
       exit (EXIT_FAILURE);
     }
 
@@ -99,14 +99,14 @@ setup_environment (void)
     xfsm_enable_verbose ();
 
   /* pass correct DISPLAY to children, in case of --display in argv */
-  xfce_setenv ("DISPLAY", gdk_display_get_name (gdk_display_get_default ()), TRUE);
+  g_setenv ("DISPLAY", gdk_display_get_name (gdk_display_get_default ()), TRUE);
 
   /* this is for compatibility with the GNOME Display Manager */
   lang = g_getenv ("GDM_LANG");
   if (lang != NULL && strlen (lang) > 0)
     {
-      xfce_setenv ("LANG", lang, TRUE);
-      xfce_unsetenv ("GDM_LANG");
+      g_setenv ("LANG", lang, TRUE);
+      g_unsetenv ("GDM_LANG");
     }
 
   /* check access to $ICEAUTHORITY or $HOME/.ICEauthority if unset */
@@ -143,13 +143,6 @@ init_display (XfsmManager   *manager,
 
   sm_init (channel, disable_tcp, manager);
 
-  /* start xfsettingsd */
-  if ( !g_spawn_command_line_async ("xfsettingsd", NULL))
-  {
-    g_warning ("Could not start xfsettingsd");
-  }
-
-
   /* gtk resource files may have changed */
   gtk_rc_reparse_all ();
 }
@@ -179,8 +172,8 @@ xfsm_dbus_init (void)
                                NULL);
   if (DBUS_REQUEST_NAME_REPLY_PRIMARY_OWNER != ret)
     {
-      g_error ("Another session manager is already running");
-      exit (1);
+      g_printerr ("%s: Another session manager is already running\n", PACKAGE_NAME);
+      exit (EXIT_FAILURE);
     }
 }
 
@@ -199,45 +192,90 @@ xfsm_dbus_cleanup (void)
                          "org.xfce.SessionManager", NULL);
 }
 
+static gboolean
+xfsm_dbus_require_session (gint argc, gchar **argv)
+{
+  gchar **new_argv;
+  gchar  *path;
+  gint    i;
+  guint   m = 0;
+
+  if (g_getenv ("DBUS_SESSION_BUS_ADDRESS") != NULL)
+    return TRUE;
+
+  path = g_find_program_in_path ("dbus-launch");
+  if (path == NULL)
+    {
+      g_critical ("dbus-launch not found, the desktop will not work properly!");
+      return TRUE;
+    }
+
+  /* avoid rondtrips */
+  g_assert (!g_str_has_prefix (*argv, "dbus-launch"));
+
+  new_argv = g_new0 (gchar *, argc + 4);
+  new_argv[m++] = path;
+  new_argv[m++] = "--sh-syntax";
+  new_argv[m++] = "--exit-with-session";
+
+  for (i = 0; i < argc; i++)
+    new_argv[m++] = argv[i];
+
+  if (!execvp ("dbus-launch", new_argv))
+    {
+      g_critical ("Could not spawn %s: %s", path, g_strerror (errno));
+    }
+
+  g_free (path);
+  g_free (new_argv);
+
+  return FALSE;
+}
+
 int
 main (int argc, char **argv)
 {
-  XfsmManager     *manager;
-  XfsmShutdownType shutdown_type;
-  GError          *error = NULL;
-  GdkDisplay      *dpy;
-  XfconfChannel   *channel;
+  XfsmManager      *manager;
+  GError           *error = NULL;
+  GdkDisplay       *dpy;
+  XfconfChannel    *channel;
+  XfsmShutdownType  shutdown_type;
+  XfsmShutdown     *shutdown_helper;
+  gboolean          succeed = TRUE;
+
+  if (!xfsm_dbus_require_session (argc, argv))
+    return EXIT_SUCCESS;
 
   xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
 
   /* install required signal handlers */
   signal (SIGPIPE, SIG_IGN);
 
-  if (!gtk_init_with_args (&argc, &argv, "", option_entries, GETTEXT_PACKAGE, &error)) {
-    g_error ("%s", error->message);
-    g_error_free (error);
-    return EXIT_FAILURE;
-  }
+  if (!gtk_init_with_args (&argc, &argv, "", option_entries, GETTEXT_PACKAGE, &error))
+    {
+      g_print ("%s: %s.\n", G_LOG_DOMAIN, error->message);
+      g_print (_("Type '%s --help' for usage."), G_LOG_DOMAIN);
+      g_print ("\n");
+      g_error_free (error);
+      return EXIT_FAILURE;
+    }
 
   if (opt_version)
     {
-      g_print ("%s %s (Xfce %s)\n\n", PACKAGE_NAME, PACKAGE_VERSION, xfce_version_string ());
-      g_print ("%s\n", "Copyright (c) 2003-2011");
+      g_print ("%s %s (Xfce %s)\n\n", G_LOG_DOMAIN, PACKAGE_VERSION, xfce_version_string ());
+      g_print ("%s\n", "Copyright (c) 2003-2012");
       g_print ("\t%s\n\n", _("The Xfce development team. All rights reserved."));
-      g_print ("%s\n\n", _("Written by Benedikt Meurer <benny@xfce.org>."));
-      g_print (_("Built with Gtk+-%d.%d.%d, running with Gtk+-%d.%d.%d"),
-               GTK_MAJOR_VERSION, GTK_MINOR_VERSION, GTK_MICRO_VERSION,
-               gtk_major_version, gtk_minor_version, gtk_micro_version);
-      g_print ("\n");
       g_print (_("Please report bugs to <%s>."), PACKAGE_BUGREPORT);
       g_print ("\n");
+
       return EXIT_SUCCESS;
     }
 
-  if (G_UNLIKELY (!xfconf_init (&error))) {
-    xfce_dialog_show_error (NULL, error, _("Unable to contact settings server"));
-    g_error_free (error);
-  }
+  if (!xfconf_init (&error))
+    {
+      xfce_dialog_show_error (NULL, error, _("Unable to contact settings server"));
+      g_error_free (error);
+    }
 
   /* fake a client id for the manager, so the legacy management does not
    * recognize us to be a session client.
@@ -269,12 +307,28 @@ main (int argc, char **argv)
 
   gtk_main ();
 
+  xfsm_startup_shutdown ();
+
   shutdown_type = xfsm_manager_get_shutdown_type (manager);
+
+  /* take over the ref before we release the manager */
+  shutdown_helper = xfsm_shutdown_get ();
+
   g_object_unref (manager);
   g_object_unref (channel);
 
   xfsm_dbus_cleanup ();
   ice_cleanup ();
 
-  return xfsm_shutdown (shutdown_type);
+  if (shutdown_type == XFSM_SHUTDOWN_SHUTDOWN
+      || shutdown_type == XFSM_SHUTDOWN_RESTART)
+    {
+      succeed = xfsm_shutdown_try_type (shutdown_helper, shutdown_type, &error);
+      if (!succeed)
+        g_warning ("Failed to shutdown/restart: %s", ERROR_MSG (error));
+    }
+
+  g_object_unref (shutdown_helper);
+
+  return succeed ? EXIT_SUCCESS : EXIT_FAILURE;
 }
