@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -140,7 +140,7 @@ sm_init (XfconfChannel *channel,
   ice_setup_listeners (num_listeners, listen_objs, manager);
 
   network_idlist = IceComposeNetworkIdList (num_listeners, listen_objs);
-  xfce_setenv ("SESSION_MANAGER", network_idlist, TRUE);
+  g_setenv ("SESSION_MANAGER", network_idlist, TRUE);
   free (network_idlist);
 }
 
@@ -266,7 +266,7 @@ sm_save_yourself_request (SmsConn   sms_conn,
                     save_type == SmSaveLocal ? "Local"
                     : (save_type == SmSaveGlobal ? "Global" : "Both"));
       xfsm_verbose ("   Shutdown:       %s\n", shutdown ? "True" : "False");
-      xfsm_verbose ("   Interact Style: %s\n", 
+      xfsm_verbose ("   Interact Style: %s\n",
                     interact_style == SmInteractStyleNone ? "None"
                     : (interact_style == SmInteractStyleErrors ? "Errors" : "Any"));
       xfsm_verbose ("   Fast:           %s\n", fast ? "True" : "False");
