@@ -28,8 +28,9 @@
 #include <xfconf/xfconf.h>
 #include <libxfce4util/libxfce4util.h>
 
-#include "xfsm-client.h"
-#include "shutdown.h"
+#include <xfce4-session/xfsm-client.h>
+#include <xfce4-session/xfsm-global.h>
+#include <xfce4-session/xfsm-shutdown.h>
 
 G_BEGIN_DECLS
 
@@ -155,4 +156,6 @@ gboolean xfsm_manager_get_use_failsafe_mode (XfsmManager *manager);
 gboolean xfsm_manager_get_compat_startup (XfsmManager          *manager,
                                           XfsmManagerCompatType type);
 
+gboolean xfsm_manager_get_start_at (XfsmManager *manager);
+
 #endif /* !__XFSM_MANAGER_H__ */
