@@ -153,9 +153,28 @@ xfsm_startup_init (XfconfChannel *channel)
   gchar       *cmd;
   const gchar *ssh_agent_pid;
   pid_t        pid;
+  gboolean     gnome_keyring_found;
 
   if (xfconf_channel_get_bool (channel, "/startup/ssh-agent/enabled", TRUE))
     {
+      /* if GNOME compatibility is enabled and gnome-keyring-daemon
+       * is found, skip the gpg/ssh agent startup and wait for
+       * gnome-keyring, which is probably what the user wants */
+      if (xfconf_channel_get_bool (channel, "/compat/LaunchGNOME", FALSE))
+        {
+          cmd = g_find_program_in_path ("gnome-keyring-daemon");
+          gnome_keyring_found = (cmd != NULL);
+          g_free (cmd);
+
+          if (gnome_keyring_found)
+            {
+              g_print ("xfce4-session: %s\n",
+                       "GNOME compatibility is enabled and gnome-keyring-daemon is "
+                       "found on the system. Skipping gpg/ssh-agent startup.");
+              return;
+            }
+        }
+
       agent = xfconf_channel_get_string (channel, "/startup/ssh-agent/type", NULL);
       if (g_strcmp0 (agent, "gpg-agent") == 0
           || g_strcmp0 (agent, "ssh-agent") == 0)
@@ -845,6 +864,7 @@ xfsm_startup_start_properties (XfsmProperties *properties,
   gint             n;
   const gchar     *current_directory;
   GPid             pid;
+  GError          *error = NULL;
 
   /* release any possible old resources related to a previous startup */
   xfsm_properties_set_default_child_watch (properties);
@@ -859,49 +879,34 @@ xfsm_startup_start_properties (XfsmProperties *properties,
 
   current_directory = xfsm_properties_get_string (properties, SmCurrentDirectory);
 
-  /* fork a new process for the application */
-#ifdef HAVE_VFORK
-  /* vfork() doesn't allow you to do anything but call exec*() or _exit(),
-   * so if we need to set the working directory, we can't use vfork() */
-  if (current_directory == NULL)
-    pid = vfork ();
-  else
-#endif
-    pid = fork ();
-
-  /* handle the child process */
-  if (pid == 0)
+  if (!g_spawn_async (current_directory,
+                      argv, NULL,
+                      G_SPAWN_DO_NOT_REAP_CHILD | G_SPAWN_SEARCH_PATH,
+                      NULL, NULL,
+                      &pid, &error))
     {
-      /* execute the application here */
-      if (current_directory)
-        {
-          if (chdir (current_directory))
-            g_warning ("Unable to chdir to \"%s\": %s", current_directory, strerror (errno));
-        }
-      execvp (argv[0], argv);
-      _exit (127);
-    }
+      g_warning ("Unable to launch \"%s\": %s",
+                 *argv, error->message);
+      g_error_free (error);
+      g_strfreev (argv);
 
-  /* cleanup */
-  g_strfreev (argv);
-
-  /* check if we failed to fork */
-  if (G_UNLIKELY (pid < 0))
-    {
-      /* tell the user that we failed to fork */
-      perror ("Failed to fork new process");
       return FALSE;
     }
 
+  xfsm_verbose ("Launched command \"%s\" with PID %dn", *argv, (gint) pid);
+
+  g_strfreev (argv);
+
   properties->pid = pid;
 
   /* set a watch to make sure the child doesn't quit before registering */
-  child_watch_data = g_new (XfsmStartupData, 1);
+  child_watch_data = g_new0 (XfsmStartupData, 1);
   child_watch_data->manager = g_object_ref (manager);
   child_watch_data->properties = properties;
-  g_child_watch_add_full (G_PRIORITY_LOW, properties->pid,
-                          xfsm_startup_child_watch, child_watch_data,
-                          (GDestroyNotify) xfsm_startup_data_free);
+  child_watch_data->properties->child_watch_id =
+      g_child_watch_add_full (G_PRIORITY_LOW, properties->pid,
+                              xfsm_startup_child_watch, child_watch_data,
+                              (GDestroyNotify) xfsm_startup_data_free);
 
   /* set a timeout -- client must register in a a certain amount of time
    * or it's assumed to be broken/have issues. */
